@@ -195,7 +195,7 @@ class TimeInForce(str, Enum):
     GTC = "gtc"
     OPG = "opg"
     CLS = "cls"
-    IOC = "iok"
+    IOC = "ioc"
     FOK = "fok"
 
 
@@ -274,3 +274,10 @@ class TradeEvent(str, Enum):
     CANCELED = "canceled"
     NEW = "new"
     PARTIAL_FILL = "partial_fill"
+
+
+class QueryOrderStatus(str, Enum):
+
+    OPEN = "open"
+    CLOSED = "closed"
+    ALL = "all"
